package org.atea.nlptools.koreromaoriproxy.models;

import java.util.List;

/**
 * Defines the transcription object received from the Reo Tuhituhi API.
 */
public final class TranscriptionResult {
	private String log;
	private List<TranscriptionResultMetadata> metadata;
	private String modelVersion;
	private Boolean success;
	private String transcription;

	/**
	 * Initialises an empty instance of the {@link TranscriptionResult} class.
	 */
	public TranscriptionResult() {

	}

	/**
	 * Initialises a new instance of the {@link TranscriptionResult} class.
	 * 
	 * @param log
	 * @param metadata
	 * @param modelVersion
	 * @param success
	 * @param transcription
	 */
	public TranscriptionResult(
		String log,
		List<TranscriptionResultMetadata> metadata,
		String modelVersion,
		Boolean success,
		String transcription)
	{
		this.log = log;
		this.metadata = metadata;
		this.modelVersion = modelVersion;
		this.success = success;
		this.transcription = transcription;
	}

	/**
	 * Initialises a new instance of the {@link TranscriptionResult} class, with the intention of logging an unsuccessful result. 
	 * As such, each field is set to null bar the provided log, and {@link getSuccess} being set to false.
	 * 
	 * @param log
	 */
	public TranscriptionResult(
		String log)
	{
		this.log = log;
		this.metadata = null;
		this.modelVersion = null;
		this.success = false;
		this.transcription = null;
	}

	public String getLog()
	{
		return log;
	}
	
	public List<TranscriptionResultMetadata> getMetadata()
	{
		return metadata;
	}
	
	public String getModelVersion()
	{
		return modelVersion;
	}
	
	public Boolean getSuccess()
	{
		return success;
	}
	
	public String getTranscription()
	{
		return transcription;
	}
}
